# Nxscli-mpl
![master workflow](https://github.com/railab/nxscli-mpl/actions/workflows/master.yml/badge.svg)

Matplotlib extension to Nxscli.

## Features

* Plotting with [Matplotlib](https://github.com/matplotlib/matplotlib),
  * static time-series capture (`m_snap`)
  * animation plots (`m_live`, `m_roll`)
  * static and streaming FFT (`m_fft`, `m_fft_live`)
  * static and streaming histogram (`m_hist`, `m_hist_live`)
  * static and streaming XY (`m_xy`, `m_xy_live`)
  * static and streaming polar (`m_polar`, `m_polar_live`)
  * Matplotlib style configuration (`mpl`)

## Installation

Nxscli-mpl can be installed by running `pip install nxscli-mpl`.

To install latest development version, use:

`pip install git+https://github.com/railab/nxscli-mpl.git`
